function [hout, coors] = arrow(coors, arlen);
% function [h, coors] = arrow(coors, arlen): Draws an arrow on a figure 
% (typically from a gtext label to a data line).
% To use:
%         -click at end of text,
%         -click again at (approx) same y, but to left or right to show
%          horizontal stub line direction,
%         -click where you want the tip of the arrow.
% (arguments are optional - they get used by DARROW).
% Returns handles "h" of line and arrow-head.
% Can be called as arrow([1 1 2 2 3 3]) for specified coordinates.
% argument "arlen" is length of head (default 0.06); call as
% arrow([], arlen) if wanting to specify this while using mouse.
% Written by Roger Moss

% Written by Roger Moss, January 1994.

% set arrow head max length in terms of min axis length:
if nargin<2, arlen = 0.06; end
GCF = gcf;
GCA = gca;
col = get(GCF,'DefaultTextColor');

%read current axes
lims = axis;
PaperP = get(GCF, 'PaperPosition');
[rpos, raxis, linlog] = multaxp(GCA, 'paper');
raxl = rpos(3:4) .* PaperP(3:4);

if nargin == 0,
 [x, y] = ginput(3);
 y(2) = y(1);
elseif isempty(coors),
 [x, y] = ginput(3);
 y(2) = y(1);
else
 if size(coors, 1)==1,
     coors = reshape(coors, [length(coors)/2 2])';
 end    
 if size(coors,1)==2, coors = coors([1 1 2],:); end 
 x = coors(1:3,1);
 y = coors(1:3,2);
end

h = line(x,y);
set(h, 'Color', col)

% Now add arrow head:
[xn, yn] = sccoor(raxis, [0 raxl(1) 0 raxl(2)], [x y], [linlog; 0 0]);
l2 = sqrt((xn(3)-xn(2))^2 + (yn(3)-yn(2))^2);
mina = min(raxl);
rh = arlen * mina;
if rh > 0.8 * l2, rh = 0.8 * l2; end

if xn(2) ~= xn(3),
 ang = atan((yn(3)-yn(2))/(xn(3)-xn(2)));
 rh = rh * sign(xn(3)-xn(2));
else
 ang = 2 * atan(1);
 rh = rh * sign(yn(3)-yn(2));
end
 
dang = [-0.2:.04:0.2]';
xp = [xn(3); xn(3) - (rh * cos(ang + dang))]; 
yp = [yn(3); yn(3) - (rh * sin(ang + dang))];
[xp, yp] = sccoor([0 raxl(1) 0 raxl(2)], raxis, [xp yp], [0 0; linlog]);
hp =patch(xp, yp, col);
set(hp, 'EdgeColor', col);
h = [h; hp];
% reset axes in case arrow went ouside them !:

axis(lims);

if nargout ==1, hout = h; end
coors = [x y];
