function [Fdashi, Fdasho] = fdash_pde2(shape, conditions, show, hmax)


if nargin<1
    shape.pdelta = [0.008 0.004];
    shape.ab =  [0.004 0.003];
    shape.centre = [0 0.0002];
    shape.c = 0.5;  % metal cond
end
if nargin<2
    conditions.S = 1000;  % W/m^2
    conditions.UL = 4;
    conditions.hi = 100;
    conditions.Ta = 30;
    conditions.Tf = 70;
end
%--------------------------------------
% at edge, heat flux = c*grad(U) = S + UL(Ta-U)
% "n*(c*grad(u)) + q*u = g" with
% g = S + UL*Ta, q = UL

% Top edge:
top.q = conditions.UL;
top.g = conditions.S + conditions.UL * conditions.Ta;

% sides:
sides.g = 0;
sides.q = 0;

% internal edges:
inside.q = conditions.hi;
inside.g = conditions.hi * conditions.Tf;
%--------------------------------------

R1 = [3; 4; my_rect(shape.pdelta, [0 0])];
if strcmp(shape.type, 'rect'),
    R2 = [3; 4; my_rect(shape.ab, shape.centre)];
    geom = [R1,R2];
    ns = (char('R1','R2'))';
    sf = 'R1-R2';
elseif strcmp(shape.type, 'circle'),
    
else
    error('Shape unknown')
end
% Create geometry
gd = decsg(geom,sf,ns);
% Now create the class geometry representation
mc_model = createpde();
gm = geometryFromEdges(mc_model, gd);
% Plot the geometry
pdegplot(gm, 'EdgeLabels','on');
axis equal
% Observe that the geometry is appended to the PDEModel
% mc_model;
applyBoundaryCondition(mc_model, 'neumann', 'edge', 1, 'q', top.q, 'g', top.g);
applyBoundaryCondition(mc_model, 'neumann', 'edge', [2 6 7], 'q', sides.q, 'g', sides.g);
applyBoundaryCondition(mc_model, 'neumann', 'edge', [3 4 5 8], 'q', inside.q, 'g', inside.g);
specifyCoefficients(mc_model, 'c', shape.c, 'm', 0, 'a', 0, 'f', 0, 'd', 0);
if nargin<4
  generateMesh(mc_model); %, 'hmax', min((shape.pdelta([1 2 2])-shape.ab([1 2 2]))/2+shape.centre([1 2 2]).*[1 1 -1]) /2);
else
  generateMesh(mc_model, 'hmax', hmax, 'GeometricOrder', 'quadratic');
end

result = solvepde(mc_model);
T = result.NodalSolution;

if show
    disp(mc_model.Mesh)
    showmesh = {'off','on'};
    %pdeplot(mc_model,'XYData',u,'ZData',u,'Mesh','off'); shading interp; colormap hsv
    hp = pdeplot(mc_model,'XYData',T,'Mesh',showmesh{show}); colormap hsv;
    xd = get(hp(1), 'xdata');
    hp2 = copyobj(hp(1), gca); set(hp2, 'xdata', xd+shape.pdelta(1))
    hp3 = copyobj(hp(1), gca); set(hp3, 'xdata', xd-shape.pdelta(1)) 
    axis([shape.pdelta(1)*[-1 1]*1.5, shape.pdelta(2)*[-1 1]/2]); axis equal
   % DA = get(gca, 'dataaspectratio');
   % DA(1:2) = [1 1]*sqrt(prod(DA(1:2)));
   % set(gca,'dataaspectratio', DA)
    xlabel('x')
    ylabel('y')
    set(gca,'vis','off')
end

[xq, yq, sq] = rect_ipoints(shape.ab, shape.centre, 500); % need >200 for highest h, lowest k condition
Twi = interpolateSolution(result, xq, yq);
qu = conditions.hi*trapz(sq, Twi-conditions.Tf);
Fdashi = qu/(shape.pdelta(1)*(conditions.S - conditions.UL*(conditions.Tf-conditions.Ta)));

f = (-100:100)'/200;
sq2 = shape.pdelta(1)*f;
Two = interpolateSolution(result, sq2, shape.pdelta(2)*ones(201,1)/2);
qo = shape.pdelta(1)*conditions.S + conditions.UL*trapz(sq2, conditions.Ta-Two);
Fdasho = qo/(shape.pdelta(1)*(conditions.S - conditions.UL*(conditions.Tf-conditions.Ta)));



