function S = friction_factors(Re, e_D, Po)
% function S = friction_factors(Re, e_D, Po)
% e_D is relative roughness height, defaults to 0
% Poiseulle number defaults to 16 for circular tube
% This is the FANNING friction factor, like 16/Re, not Darcy
%
% fields .Blasius
% .Petukhov
% .Churchill
% NB: some code will "hide" Po & NuH as fields in fp (fluid properties)

if nargin<2, e_D = 0; end
if nargin<3, Po = 16; end

szRe = size(Re);
f = zeros(szRe);

% start with Blasius formula, take down to Re=4000, then interpolate (bit
% dodgy).
trans_start = 2000;  % 2100? 2320?
trans_end = 4000;

f_lam = Po./Re;
f_turb = 0.079*Re.^-0.25;
f_lamlimit = repmat(Po/trans_start, szRe);
f_turblimit = repmat(0.079*trans_end.^-0.25, szRe);

[fleft, fminus, fplus, fright] = interp_fac(trans_start, trans_end, Re);
S.Blasius = fleft.*f_lam + fminus.*f_lamlimit + fplus.*f_turblimit + fright.*f_turb;
%====================================================================
Petukhov = 0.25 ./ (0.79*log(Re)-1.64).^2;  % 0.25 converts Darcy to Fanning
Petukhov_limit = 0.25 ./ (0.79*log(3000)-1.64).^2;
[fleft, fminus, fplus, fright] = interp_fac(trans_start, 3000, Re);
S.Petukhov = fleft.*f_lam + fminus.*f_lamlimit + fplus.*Petukhov_limit + fright.*Petukhov;

% Churchill:
oRe = 1 ./Re;
A = (-2.457*log((7.*oRe).^0.9 + 0.27*e_D)).^16;
B = (37530*oRe).^16;
S.Churchill = 2*((8*oRe).^12 + 1./(A+B).^1.5).^(1/12);




