function [mdot, DP, W_pumpTP, Ah, f, Nu] = get_mdot(Re, ext_LD, panel_LDN, fp, nbends)
% function get_mdot(Re, ext_LD, Wp, L, Dh, N, fp, nbends)
% do laminar if Re<2000, turbulent if >4000, else linear interp.
% Can use ext_LD = [] if not required - then pipe has zero pressure drop
%
% Use column vectors
% Include Po and NuH as fields in fluids property structure "fp".
% 


% panel flow:
A = panel_LDN(3) * pi*panel_LDN(2).^2/4; % total channel cross-section area
rhov = Re.*fp.mu ./ panel_LDN(2);  % rho * v in channels
mdot = rhov * A;  % total system mass flow
Q = mdot/fp.rho;  % total system volume flow rate

[DP_panel, h, f, Nu] = get_DP(Re(:), rhov, panel_LDN, fp, nbends);


if isempty(ext_LD),
    DP_pipe = 0;
else
    % pipe flow
    Apipe = pi*ext_LD(2)^2/4; % N=1, pipe area
    rhov_pipe = mdot/Apipe;
    Re_pipe = rhov_pipe * ext_LD(2)/fp.mu;
    DP_pipe = get_DP(Re_pipe, rhov_pipe, ext_LD, fp, 0);
end

% combine:
DP = DP_panel + DP_pipe;
W_pumpTP = [Q .* DP, Q.*DP_panel];  % total, panel
Ah = pi*prod(panel_LDN)*h;  % total surface area of tubes * hi




%================================================================
function [DP, h, f, Nu] = get_DP(Re, rhov, LD, fp, nbends)
% Hassoon add L/D=14 per bend in turbulent flow

[f, Nu] = gnielinski(fp.Pr, Re, [fp.Po fp.NuH]);
DP = 4 * f * (LD(1) / LD(2) + nbends*14) .* rhov.^2 /(2*fp.rho);
h = Nu*fp.k/LD(2);



