function [fleft, fminus, fplus, fright] = interp_fac(LLim, ULim, x)
% [fleft, fminus, fplus, fright] = interp_fac(LLim, ULim, x) OR
% [fleft, fright] = interp_fac(LLim, ULim, x)
% Use for interpolation through transition region.
% fleft+fminus+fplus+fright = 1 OR fleft+fright = 1
% 
%
% Two modes of operation:
% (a) You have f specified by two correlations and AT EACH RE you want
% one or other or some linear combination, e.g:
% F1 = laminar(Re); F2 = turbulent(Re) % these are spoof!
% [fleft, fright] = interp_fac(2100, 3000, Re);
% f = fleft.*F1 + fright.*F2
%
% (b) in the transition region you want to interpolate between 
% f_2000 and f_3000 (say) at Re = 2000 and Re = 3000
% Then do:
% [fleft, fminus, fplus, fright] = interp_fac(2000, 3000, Re);
% f = fleft.*F1 + fminus.*f_2000 + fplus.*f_3000 + fright.*F2


f = (x-LLim) / (ULim - LLim);  % for linear interpolation 
fleft = f<0;  % logical, =1 in left region
fright = f>1;

fplus = f;
fplus(fleft | fright) = 0;
fminus = 1 - fplus;
fminus(fleft | fright) = 0;


if nargout==2,
    fleft = fleft+fminus;
    fminus = fplus+fright;
elseif nargout~=4,
    error('Must call with 2 or 4 output arguments')
end
