function [DTfm, DTh, v, mdot, Re, DP] = plate_deltat_e14(R, D, L, Wp, S, Po, NuH, fp);
% [DTfm, DTh, v, mdot, Re, DP] = plate_deltat_e14(R, D, L, Wp, S, Po, NuH, fp);
% >> rewritten for Eurosun paper
%
% R = fraction of metal removed on centre-line eg 2/pi equiv to 50/50 square
% D = hydraulic diameter
% L = length of plate
% Plate is B = 1 m wide
% S = net heat input W/m^2
% Po = Poisseule friction constant, to give f = Fa/Re;
% NuH = Nusselt number for this duct shape at constant heat flux
% fp = fluid properties structure from fluid_properties.m
%
% R = 0.5; N = (50:25:1000)'; D = R ./ N;
% fp = fluid_properties('paratherm-mr', [], 120);
% [DTfm, DTh, V, mdot, Re, DP] = plate_deltat(R, D, 1, 1, S, 3.6, fp );
% plot(D, [DTh, DTfm, DTh+DTfm])
% hold
% [DTfm, DTh, V, mdot, Re, DP] = plate_deltat(R, D, 1, 0.1, S, 3.6, fp );
% plot(D, [DTh, DTfm, DTh+DTfm])
% [DTfm, DTh, V, mdot, Re, DP] = plate_deltat(R, D, 1, 0.001, S, 3.6, fp );
% plot(D, [DTh, DTfm, DTh+DTfm])
% [DTfm, DTh, V, mdot, Re, DP] = plate_deltat(R, D, 1, 0.0001, S, 3.6, fp );
% plot(D, [DTh, DTfm, DTh+DTfm])
% axis([0 0.01 0 12])
% xlabel('D_H'); ylabel('Temperature difference')
% legend({'DTpf';'DTf (f_{pp} = 1%)';'DT_{pf}+DT_f/2 (f_{pp} = 1%)';'DT_{pf}+DT_f/2 (f_{pp} = 0.1%)';'DT_{pf}+DT_f/2 (f_{pp} = 0.01%)'})
% grid
% title('Paratherm at 100 degC, b = 1m')

% fp = fluid_properties('paratherm-mr', [], 120)
%           c: 2600
%           k: 0.1290
%          mu: 0.0011
%         rho: 717

c = fp.c;
k = fp.k;
mu = fp.mu;
rho = fp.rho;


DTh = S*D ./ (pi*k*NuH*R); % fluid to metal temperature difference,
% as in Q = A*h*DTh


DTfm = (2*S*L/(rho*c)) * sqrt(Po*mu./(2*pi*R*Wp)) .* (D.^(-1.5)); % flow mean delta T
% = (To-Ti)/2


v = sqrt(2*D .* Wp ./ (Po*pi*mu*R));
mdot = (rho * D.^1.5).*sqrt(2*pi*R*Wp/(Po*mu))/4; % per metre width
Re = rho * v .* D / mu;

DP = 2*Po * mu * L .* v ./ D.^2;



