% version 3 includes turbulent calculation for figs 9(b) and 10
clear

lstyles = {'- '
    '--'
    '-.'
    ': '
    'o-'
    '^-'
    '*-'};
figure
set(gcf, 'defaultaxesfontsize', 12, 'defaulttextfontsize', 12,...
    'defaultaxeslinewidth', 1, 'defaultlinelinewidth', 2,...
    'paperunits', 'inches',...
    'paperposition',[0 0 6.4 4], 'papersize', [6.4 4],...
    'defaultaxeslinestyleorder', lstyles)
hax(1) = gca;
hax(2)= axes('vis','off');
axes(hax(1))

arrow_colour = [1 1 1]*0.4;

%fp = fluid_properties('paratherm-mr', [], 120);
fp = fluid_properties('tyfocor-ls', [], 70);

%kdelta = 390 * 0.001;  % 1 mm copper
kdelta = [222  0.0009];  % 0.9 mm 1050 aluminium
Cb = Inf;
ext_LD = [];  % panel only

titles = {'Microchannel','Serpentine'};
nSerp = 1;
if ~nSerp  % microchannel, square, 50/50
    R = 2/pi;
    fp.Po = 14.227;
    fp.NuH = 3.612;
    Wp = [100 1 0.1 0.01];
    WH = [1 10; 1 1; 1 1; 1 1]; %repmat([1 1], [3 1]);
    Dh=0.0002:0.0001:0.01;
    axlims = [  0 0.01 0.97 1; 
                0 0.01 0 3000];
    line_leg = {'1000 W, H = 10 m', '1 W, H = 1m', '0.1 W, H = 1 m', '0.01 W, H = 1 m'};
    arrow_coors = [ 0.002 0.9815 0 0.9815;
                    0.0032 500 0.0055 500];
else  % serpentine
    % R = [0.2 0.1 0.05];
    R = [0.15 0.1 0.05];
    fp.Po = 16;
    fp.NuH = 4.36;
    Wp = [0.1 ]; % was 1
    WH = [1 1];
    Dh=0.0004:0.0002:0.02;
    axlims = [  0 0.02 0.8 1; 
                0 0.02 0 1e4];
    line_leg = {'R = 0.15', 'R = 0.1', 'R = 0.05', 'F = 1'};
    arrow_coors = [ 0.0049 0.9 0 0.9;
                    0.016 3600 0.02 3600];

end


lines = {'-','--','-.'};
colours = {[1 1 1]*0, [1 1 1]*0.2, [1 1 1]*0.4, [1 1 1]*0.6};
colours = {[0 0 1], [0 0.6 0], [1 1 1]*0.4, [1 1 1]*0.6};
markers = {'o','^','*','v'};

% UL = [1 3.8];
UL = 3.8;
%lwidths = [1.5 2.5];
lwidths = [1 2.5 4];

h = [];

for i = 1:length(R)  % originally UL (...1.m), now R
    for j = 1,  %:length(Wp)  % Wp
        [F, Fdash, FR(:,i), mstar(:,i), Re(:,i), mdot(:,j,i)] = db_analysis4a(UL, R(i), Dh, fp, Wp(j), WH(j,:), nSerp, kdelta, Cb, ext_LD);
        [F, Fdash, FRinf(:,i), mstar(:,i), Re(:,i)] = db_analysis4a(UL, R(i), Dh, fp, Wp(j), WH(j,:), nSerp, [Inf 0.001], Cb, ext_LD);
        if ~nSerp, 
           AorH = WH(j,2); % scale by H
        else
            AorH = prod(WH(j,:));
        end
        ReoAH(:,i) = Re(:,i)/AorH;
        mdotoA(:,i) = mdot(:,i) / prod(WH(j,:));
    end
    
end

% find nominal flow rate points
flows = [0.02 0.05 0.1 0.15]';
for j = 1:length(R)
    DhFR_int = interp1(mdotoA(:,j), [Dh(:) FR(:,j)], flows);
    DH_int(:,j) = DhFR_int(:,1);
    FR_int(:,j) = DhFR_int(:,2);
end


fig9_10 = 10; % varying R
if fig9_10==9
    axes(hax(1))
    yyaxis left
    hold off
    hleft = plot(Dh, FR, Dh, FRinf, '.');
    for i = 1:length(Wp), set(hleft(i+[0 3]), 'color', colours{i}); end
    if ~nSerp, set(hleft(5:8), 'vis','off'); end
    hold on
    for i = 1:size(DH_int,1) 
        for j = 1:size(DH_int,2)
            hm(i,j) = plot(DH_int(i,j), FR_int(i,j), 'markersize', 8,'linestyle','none');
        end 
    end
    for i = 1:4, set(hm(i,:), 'marker', markers{i}); end
    for j = 1:3, set(hm(:,j), 'color', colours{j}); end
    axis(axlims(1,:))
    ha1 = arrow(arrow_coors(1,:));
    set(ha1(1), 'color', get(hleft(1), 'color'))
    set(ha1(2), 'facecolor', get(hleft(1), 'color'))
    xlabel('D_h  (m)')
    ylabel('F_R')
    title(titles{nSerp+1})
    
    yyaxis right
    hold off
    hright = plot(Dh, ReoAH)
    for i = 1:length(Wp), set(hright(i), 'color', colours{i}); end
    axis(axlims(2,:))
    hold on
    ha2 = arrow(arrow_coors(2,:));
    set(ha2(1), 'color', get(hright(1), 'color'))
    set(ha2(2), 'facecolor', get(hright(1), 'color'))
    %if ~isSerp, ylabel('Re/H  (m^{-1})'); else ylabel('Re/A  (m^{-2})'); end
        if ~nSerp, ylabel('Re/H  (m^{-1})'); else ylabel('Re'); end
        
    grid on
    legend(hleft(1:length(line_leg)), line_leg)
    %legend(h(10:-1:7), {'1000 W, 10 m^2', '1 W, 1 m^2', '0.001 W, 0.1 m^2', 'F = 1'})
    
    axes(hax(2))
    legend(hax(2), hm(:,1), {'0.02 kg/m^2s','0.05 kg/m^2s','0.1 kg/m^2s','0.15 kg/m^2s'})
    axes(hax(1))  
else
    axes(hax(1))
    yyaxis left
    hold off
    hleft = plot(Dh, FR, Dh, FRinf, ':');
    for i = 1:length(R), set(hleft(i+[0 3]), 'color', colours{i}); end
    set(hleft(4:6), 'linewidth', 1)
    if ~nSerp, set(hleft(5:8), 'vis','off'); end
    hold on
    for i = 1:size(DH_int,1) 
        for j = 1:size(DH_int,2)
            hm(i,j) = plot(DH_int(i,j), FR_int(i,j), 'markersize', 8,'linestyle','none');
        end 
    end
    for i = 1:4, set(hm(i,:), 'marker', markers{i}); end
    for j = 1:3, set(hm(:,j), 'color', colours{j}); end
    axis(axlims(1,:))
    ha1 = arrow(arrow_coors(1,:));
    set(ha1(1), 'color', colours{3}); %arrow_colour)
    set(ha1(2), 'facecolor', colours{3}); %arrow_colour)
    xlabel('D_h  (m)')
    ylabel('F_R')
    title(titles{nSerp+1})
    
    yyaxis right
    hold off
    hright = plot(Dh, ReoAH)
    for i = 1:length(R), set(hright(i), 'color', colours{i}); end
    axis(axlims(2,:))
    hax(1).YAxis(2).TickValues = [0 2500 5000 7500 10000];
    hold on
    ha2 = arrow(arrow_coors(2,:)); 
    set(ha2(1), 'color', colours{1}); %
    set(ha2(2), 'facecolor', colours{1}); %
   % if ~isSerp, ylabel('Re/H  (m^{-1})'); else ylabel('Re/A  (m^{-2})'); end
    if ~nSerp, ylabel('Re/H  (m^{-1})'); else ylabel('Re'); end
        
    grid on
    legend(hax(1), hleft(1:length(line_leg)), line_leg)
    %legend(h(10:-1:7), {'1000 W, 10 m^2', '1 W, 1 m^2', '0.001 W, 0.1 m^2', 'F = 1'})
    
    axes(hax(2))
    legend(hax(2), hm(:,1), {'0.02 kg/m^2s','0.05 kg/m^2s','0.1 kg/m^2s','0.15 kg/m^2s'})
    %axes(hax(1))
end


% find maximum points
[maxFR, I] = max(FR)  % I is row number that each came from
maxDh = Dh(I)  
