% version 4b to determine iterated best Dh for Table 2 serpentines

clear

lstyles = {'- '
    '--'
    '-.'
    ': '
    'o-'
    '^-'
    '*-'};
figure
set(gcf, 'defaultaxesfontsize', 12, 'defaulttextfontsize', 12,...
    'defaultaxeslinewidth', 1, 'defaultlinelinewidth', 2,...
    'paperunits', 'inches',...
    'paperposition',[0 0 6.4 4], 'papersize', [6.4 4],...
    'defaultaxeslinestyleorder', lstyles)
hax(1) = gca;
hax(2)= axes('vis','off');
axes(hax(1))

arrow_colour = [1 1 1]*0.4;

%fp = fluid_properties('paratherm-mr', [], 120);
fp = fluid_properties('tyfocor-ls', [], 70);

%kdelta = 390 * 0.001;  % 1 mm copper
kdelta = [222  0.0009];  % 0.9 mm 1050 aluminium
Cb = Inf;
ext_LD = [];  % panel only

titles = {'Microchannel','Serpentine'};
nSerp = 1;
if ~nSerp,  % microchannel, square, 50/50
    R = 2/pi;
    fp.Po = 14.227;
    fp.NuH = 3.612;
    Wp = [100 1 0.1 0.01];
    WH = [1 10; 1 1; 1 1; 1 1]; %repmat([1 1], [3 1]);
    Dh=0.0002:0.0001:0.01;
    axlims = [  0 0.01 0.97 1; 
                0 0.01 0 3000];
    line_leg = {'1000 W, H = 10 m', '1 W, H = 1m', '0.1 W, H = 1 m', '0.01 W, H = 1 m'};
    arrow_coors = [ 0.002 0.9815 0 0.9815;
                    0.0032 500 0.0055 500];
else  % serpentine (one branch of parallel in this case, or series)
    % R = [0.2 0.1 0.05];
    R = [0.15];
    fp.Po = 16;
    fp.NuH = 4.36;
    Wp = [3.77/4, 6.27/4 ]; % was 1
    WH = [1 2; 1 4];
    Dh=0.0004:0.0001:0.02;
    axlims = [  0 0.02 0.9 1; 
                0 0.02 0 1e4];
    line_leg = {'2.235 W, 2 m^2', '6.82 W, 4 m^2'};
    arrow_coors = [ 0.0049 0.9 0 0.9;
                    0.016 3600 0.02 3600];

end


lines = {'-','--','-.'};
colours = {[1 1 1]*0, [1 1 1]*0.2, [1 1 1]*0.4, [1 1 1]*0.6};
colours = {[0 0 1], [0 0.6 0], [1 1 1]*0.4, [1 1 1]*0.6};
markers = {'o','^','*','v'};

% UL = [1 3.8];
UL = 3.8;
%lwidths = [1.5 2.5];
lwidths = [1 2.5 4];

h = [];

for i = 1  % originally UL (...1.m), now R
    for j = 1:length(Wp)  % Wp
        [F, Fdash, FR(:,j), mstar(:,j), Re(:,j), mdot(:,j,i)] = db_analysis4a(UL, R(i), Dh, fp, Wp(j), WH(j,:), nSerp, kdelta, Cb, ext_LD);
        %[F, Fdash, FRinf(:,i), mstar(:,i), Re(:,i)] = db_analysis4a(UL, R(i), Dh, fp, Wp(j), WH(j,:), isSerp, [Inf 0.001], Cb, ext_LD);
        if ~nSerp, 
           AorH = WH(j,2); % scale by H
        else
            AorH = prod(WH(j,:));
        end
        ReoAH(:,i) = Re(:,i)/AorH;
        mdotoA(:,i) = mdot(:,i) / prod(WH(j,:));
    end
    
end



fig9_10 = 10; % varying R
if fig9_10==9
 
   
else
    axes(hax(1))
    hold off
    hleft = plot(Dh, FR);
    for i = 1:length(Wp), set(hleft(i), 'color', colours{i}); end
    axis(axlims(1,:))
    xlabel('D_h  (m)')
    ylabel('F_R')
    title('Serpentine, R = 0.15')
    grid on
    legend(hax(1), hleft(1:length(line_leg)), line_leg)
end


% find maximum points
[maxFR, I] = max(FR)  % I is row number that each came from
maxDh = Dh(I)  
