% plot effect of plate spacing on deltaT
set(gcf, 'defaultaxesfontsize', 12, 'defaulttextfontsize', 12,...
    'defaultaxeslinewidth', 1, 'defaultlinelinewidth', 2,...
    'paperunits', 'inches',... 
    'paperposition',[0 0 6.4 4], 'papersize', [6.4 4])


R = 2/pi; % equiv to 50/50 square or parallel
b = logspace(-0.6, 0.9, 50)/1000;  % Dh = 2h
D = 2*b;

S = 750;
%Fa = 14.227;  % or 16 for a circular hole, 14.227 for square
Po = 24;  % parallel plates
% circular equivalent: Po = 14.226  % square

% do single-sided first
NuH1 = 5.385 / 2;  % average with heat flux only to top half
NuH2 = 8.235;
% square equivalent: NuH2 = 3.612
H2H1 = NuH2 / NuH1;
% if heat transfer both sides, halve DTh
L = 1;

% ckmurho = [2600 0.129 0.0011 717];  % Paratherm MR at 120 deg C
%fp = fluid_properties('Paratherm-MR', [], 180);
fp = fluid_properties('tyfocor-ls', [], 70);

hold off
set(0, 'defaultaxeslinewidth', 1, 'defaultlinelinewidth', 2, 'defaultaxesfontsize', 14, 'defaulttextfontsize', 14)

% Wp = 0.01
[DTfm, DTh, V, mdot, Re, DP] = plate_deltat_e14(R, D, L, 0.01, S, Po, NuH1, fp);
I = Re<=2000; sum(I)
h = plot(D(I)/2, DTh(I)+DTfm(I), '-k', D(I)/2, DTh(I)/H2H1+DTfm(I), ':k');
hold on

% Wp = 0.1
[DTfm, DTh, V, mdot, Re, DP] = plate_deltat_e14(R, D, L, 0.1, S, Po, NuH1, fp);
I = Re<=2000; sum(I)
h = [h; plot(D(I)/2, DTh(I)+DTfm(I), '--k', D(I)/2, DTh(I)/H2H1+DTfm(I), ':k')];

% Wp = 1
[DTfm, DTh, V, mdot, Re, DP] = plate_deltat_e14(R, D, L, 1, S, Po, NuH1, fp);
I = Re<=2000;sum(I)
h = [h; plot(D(I)/2, DTh(I)+DTfm(I), '-.k', D(I)/2, DTh(I)/H2H1+DTfm(I), ':k')];
%plot(D(I)/2, DTfm(I), ':b')
%plot(D/2, DTh, '-.m')
IsFrontPlate = 1;  % else 0

plot_dhminima

axis([0 0.01 0 6])
xlabel('Plate spacing \itb \rm  (m)'); 
ylabel('\Delta\itT  \rm(K)')
legend(h([1 3 5 7 2]), {'$$\Delta T (W_p = 0.01 W/m^2)$$'
    '$$\Delta T (W_p = 0.1 W/m^2)$$'
    '$$\Delta T (W_p = 1 W/m^2)$$'
    'Optimum'
    'Both sides'}, 'interpreter','latex')

grid
%title('Paratherm MR at 180\circC, S=750W/m^2, L = 1m')
%title('Tyfocor LS at 70\circC, S=750W/m^2, L = 1m')
axis([0 0.005 0 6])

%title('$$\textrm{Paratherm MR at 120}^{\circ}\textrm{C, }R={2\over{\pi}}$$',...
%    'interp','latex')
