% plot_variousfluids
hold off
S = 750;
Po = 14.227;
NuH = 3.612;
R = 2/pi;
L = 1;
plot_type = 0  % 0 DT, 1 Re
lwidths = [1.5 1.5 1.5 2.5 2];

set(gcf, 'defaultaxesfontsize', 12, 'defaulttextfontsize', 12,...
    'defaultaxeslinewidth', 1, 'defaultlinelinewidth', 2,...
    'paperunits', 'inches',...
    'paperposition',[0 0 6.4 4], 'papersize', [6.4 4])


fp(1) = fluid_properties('paratherm-mr', [], 120);
fp(2) = fluid_properties('paratherm-mr', [], 170);
fp(3) = fluid_properties('paratherm-hr', [], 120);
fp(4) = fluid_properties('tyfocor-ls', [], 100);
fp(5) = fluid_properties('tyfocor-ls', [], 70);

for i = 1:5, fpi=fp(i);displ2(fpi.Type, fpi.th_diff, fpi.mu, fpi.th_diff*sqrt(fpi.mu), (fpi.th_diff*sqrt(fpi.mu))^0.4); end
% paratherm-mr  6.9199e-08  0.0011  2.2951e-09  0.0003502
% paratherm-mr  6.6999e-08  0.00065  1.7081e-09  0.00031118
% paratherm-hr  5.8169e-08  0.0016  2.3268e-09  0.00035213
% tyfocor-ls  1.2246e-07  0.00057643  2.9401e-09  0.00038668
% tyfocor-ls  1.1804e-07  0.0014214  4.4503e-09  0.00045641

lines = {'-k','--k','-.k',':m','-b'};
% draw lines:
Wp = logspace(-3, 1, 10);
for i = 1:5,
    Dh25 = (3* fp(i).k *NuH*L/(fp(i).rho * fp(i).c)) .* sqrt(Po * pi* fp(i).mu *R ./ (2*Wp));
    Dh = Dh25 .^ 0.4;
    [DTfm, DTh, V, mdot, Re, DP] = plate_deltat_e14(R, Dh, L, Wp, S, Po, NuH, fp(i));
    I = Re <= 2000;
    if i<4, c = [0 0 0]; else c = [1 1 1]*0.5; end
    switch plot_type
        case 0
            plot(Dh(I), DTh(I)+DTfm(I), lines{i}, 'linewidth', lwidths(i), 'color', c)
        case 1
            plot(Dh, Re, lines{i}, 'linewidth', lwidths(i), 'color', c)
        otherwise
            error('unknown plottype')
    end
    
    
    hold on
end

%------------------------
% draw points:
Wp = [0.001 0.01 0.1 1];
clear DT Dh4 REm
for i = 1:5,
    Dh25 = (3* fp(i).k *NuH*L/(fp(i).rho * fp(i).c)) .* sqrt(Po * pi* fp(i).mu *R ./ (2*Wp));
    Dh = Dh25 .^ 0.4;
    [DTfm, DTh, V, mdot, Re, DP] = plate_deltat_e14(R, Dh, L, Wp, S, Po, NuH, fp(i));
    I = Re>2000;
    DT(i,:) = DTfm + DTh;
    DT(I,:) = NaN; % not laminar
    REm(i,:) = Re;
    Dh4(i,:) = Dh;
end

markers = fliplr({'o','^','s','p'});
hm = zeros(4,1);
for i = 1:4,
    switch plot_type
        case 0
            hm(i) = plot(Dh4(:,i), DT(:,i), [markers{i} 'k'])
        case 1
            hm(i) = plot(Dh4(:,i), REm(:,i), [markers{i} 'k'])
        otherwise
            error('unknown plottype')
    end
end
set(hm, 'markersize', 8)

hl1 = legend({'Paratherm-MR, 120\circC','Paratherm-MR, 170\circC',...
    'Paratherm-HR, 120\circC',...
    'Tyfocor-LS, 100\circC',...
    'Tyfocor-LS, 70\circC'});

legax1 = copyobj([hl1 gca], gcf); % make a permanent copy
set(legax1(2), 'vis', 'off')
set(get(legax1(2),'children'), 'vis', 'off')

legend(hm, {'W_p = 0.001 W/m^2',...
    'W_p = 0.01 W/m^2',...
    'W_p = 0.1 W/m^2',...
    'W_p = 1 W/m^2'})

grid
xlabel('\itD_{h\rm,opt} \rm(m)')
switch plot_type
    case 0
        ylabel('\Delta\itT \rm(K)')
        axis([0 0.009 0 10])
    case 1
        ylabel('Reynolds number')
        axis([0 0.009 0 2000])
    otherwise
        error('unknown plottype')
end
