function [x, y] = sccoor(OldAxis, NewAxis, coors, linlog);
% function [x,y] = sccoor(OldAxis,NewAxis,coors, linlog):  Scales coordinates to maintain position wrt axes.
% This keeps position wrt the axes the same while axis limits change.
% Use OldAxis or NewAxis = axis.   coors has two columns, [x y].
% linlog corresponds to [linlog_old; linlog_new] as multaxp and defaults to [0 0; 0 0],
% i.e. both linear.  coors is in data units, so where linlog=1 will take logarithms before
% converting to normalised units; it is assumed that OldAxis etc are log10(axis), i.e. raxis
% values from multaxp.
% USED BY RECTEXT.M-CREATED FUNCTIONS.    Roger Moss

% Written by Roger Moss, November 1993.

if nargin<4, linlog = zeros(2,2); end
linlog = logical(linlog);
coors(:, linlog(1,:)) = log10(coors(:,linlog(1,:)));

sf = [(NewAxis(2)-NewAxis(1))/(OldAxis(2)-OldAxis(1)), (NewAxis(4)-NewAxis(3))/(OldAxis(4)-OldAxis(3)) ];
x = [(coors(:,1) - OldAxis(1))*sf(1) + NewAxis(1), (coors(:,2)-OldAxis(3))*sf(2) + NewAxis(3)];
x(:, linlog(2,:)) = 10.^(x(:,linlog(2,:)));

if nargout == 2,
 if length(x)>0,
  y = x(:,2); x = x(:,1);
 else
  y = [];
 end
end